==> apache-iotdb-1.3.2-source-release.zip: apache-iotdb-1.3.2/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/queryengine/plan/expression/visitor/TemplatedConcatRemoveUnExistentMeasurementVisitor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.queryengine.plan.expression.visitor;

import org.apache.iotdb.commons.path.PartialPath;
import org.apache.iotdb.db.queryengine.plan.expression.Expression;
import org.apache.iotdb.db.queryengine.plan.expression.leaf.NullOperand;
import org.apache.iotdb.db.queryengine.plan.expression.leaf.TimeSeriesOperand;
import org.apache.iotdb.tsfile.write.schema.IMeasurementSchema;

import java.util.Map;

/**
 * This class is only used for align by device query with template and value filter.
 *
 * <p>The function of this class is used to remove timeseries which is not in the template.
 */
public class TemplatedConcatRemoveUnExistentMeasurementVisitor
    extends ReconstructVisitor<Map<String, IMeasurementSchema>> {

  @Override
  public Expression visitTimeSeriesOperand(
      TimeSeriesOperand predicate, Map<String, IMeasurementSchema> context) {
    PartialPath measurementPath = predicate.getPath();
    if (context.containsKey(measurementPath.getMeasurement())) {
      return predicate;
    } else {
      return new NullOperand();
    }
  }
}

==> apache-iotdb-1.3.6-source-release.zip: apache-iotdb-1.3.6/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/queryengine/plan/expression/visitor/TemplatedConcatRemoveUnExistentMeasurementVisitor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.queryengine.plan.expression.visitor;

import org.apache.iotdb.commons.path.PartialPath;
import org.apache.iotdb.db.queryengine.plan.expression.Expression;
import org.apache.iotdb.db.queryengine.plan.expression.leaf.NullOperand;
import org.apache.iotdb.db.queryengine.plan.expression.leaf.TimeSeriesOperand;

import org.apache.tsfile.write.schema.IMeasurementSchema;

import java.util.Map;

/**
 * This class is only used for align by device query with template and value filter.
 *
 * <p>The function of this class is used to remove timeseries which is not in the template.
 */
public class TemplatedConcatRemoveUnExistentMeasurementVisitor
    extends ReconstructVisitor<Map<String, IMeasurementSchema>> {

  @Override
  public Expression visitTimeSeriesOperand(
      TimeSeriesOperand predicate, Map<String, IMeasurementSchema> context) {
    PartialPath measurementPath = predicate.getPath();
    if (context.containsKey(measurementPath.getMeasurement())) {
      return predicate;
    } else {
      return new NullOperand();
    }
  }
}
